'use strict';
var gutil = require('gulp-util');
var through = require('through2');
var chalk = require('chalk');
var prettyBytes = require('pretty-bytes');
var StreamCounter = require('stream-counter');
var gzipSize = require('gzip-size');
var notifier = require('node-notifier');

module.exports = function (opts) {
	opts = opts || {};

	var totalSize = 0;
	var fileCount = 0;
  var filesOver = false;

	function log(what, size) {
		var title = opts.title;
		title = title ? chalk.cyan(title) + ' ' : '';
		size = opts.pretty !== false ? prettyBytes(size) : (size + ' B');
		gutil.log(title + what + ' ' + chalk.magenta(size) + (opts.gzip ? chalk.gray(' (gzipped)') : ''));
	}

	return through.obj(function (file, enc, cb) {
		if (file.isNull()) {
			cb(null, file);
			return;
		}

		var finish = function (err, size) {
			if (err) {
				cb(new gutil.PluginError('gulp-size', err));
				return;
			}

			totalSize += size;

			if (opts.showFiles === true && size > 0 && opts.showFiles === true && size < 1000000) {
				log(chalk.blue(file.relative), size);
			} else {
        filesOver = true;
        log(chalk.red(file.relative), size);

				notifier.notify({
					title: 'File Over!',
					message: file.relative
				});
      }

			fileCount++;
			cb(null, file);
		};

		if (file.isStream()) {
			if (opts.gzip) {
				file.contents.pipe(gzipSize.stream())
					.on('error', finish)
					.on('end', function () {
						finish(null, this.gzipSize);
					});
			} else {
				file.contents.pipe(new StreamCounter())
					.on('error', finish)
					.on('finish', function () {
						finish(null, this.bytes);
					});
			}

			return;
		}

		if (opts.gzip) {
			gzipSize(file.contents, finish);
		} else {
			finish(null, file.contents.length);
		}
	}, function (cb) {
		this.size = totalSize;
		this.prettySize = prettyBytes(totalSize);

    if(filesOver){
      if (!(fileCount === 1 && opts.showFiles) && totalSize > 0 && fileCount > 0) {
        log(chalk.red('There are files over 1mb please check the files marked in red'), totalSize);
      }
    } else {
      if (!(fileCount === 1 && opts.showFiles) && totalSize > 0 && fileCount > 0) {
        log(chalk.green('all files under 1 MB - Total Size:'), totalSize);
      }
    }


		cb();
	});
};
